@@ -190,78 +190,101 @@ pub struct TlsPaths {
     pub ca_cert: PathBuf,
 }
 
-#[cfg(not(target_arch = "wasm32"))]
-impl TryFrom<TlsPolicy> for DomainConnector {
-    type Error = IoError;
+cfg_if::cfg_if! {
+    if #[cfg(target_arch = "wasm32")] {
 
-    fn try_from(config: TlsPolicy) -> Result<Self, Self::Error> {
-        use fluvio_future::native_tls::{
-            TlsDomainConnector, ConnectorBuilder, IdentityBuilder, X509PemBuilder,
-            PrivateKeyBuilder, CertBuilder, TlsAnonymousConnector,
-        };
-        match config {
-            TlsPolicy::Disabled => Ok(Box::new(DefaultDomainConnector::new())),
-            TlsPolicy::Anonymous => {
-                info!("Using anonymous TLS");
-                let connector: TlsAnonymousConnector = ConnectorBuilder::anonymous().build().into();
-                Ok(Box::new(connector))
+        impl TryFrom<TlsPolicy> for DomainConnector {
+            type Error = IoError;
+
+            fn try_from(_config: TlsPolicy) -> Result<Self, Self::Error> {
+                info!("Using Default Domain connector for wasm");
+                Ok(Box::new(DefaultDomainConnector::new()))
             }
-            TlsPolicy::Verified(TlsConfig::Files(tls)) => {
-                info!(
-                    domain = &*tls.domain,
-                    "Using verified TLS with certificates from paths"
-                );
+        }
 
-                let builder = ConnectorBuilder::identity(IdentityBuilder::from_x509(
-                    X509PemBuilder::from_path(&tls.cert)?,
-                    PrivateKeyBuilder::from_path(&tls.key)?,
-                )?)?
-                .add_root_certificate(X509PemBuilder::from_path(&tls.ca_cert)?)?;
+    } else {
 
-                // disable certificate verification for mac only!
-                let builder = if cfg!(target_os = "macos") {
-                    builder.no_cert_verification()
-                } else {
-                    builder
-                };
-                Ok(Box::new(TlsDomainConnector::new(
-                    builder.build(),
-                    tls.domain,
-                )))
-            }
-            TlsPolicy::Verified(TlsConfig::Inline(tls)) => {
-                info!(
-                    domain = &*tls.domain,
-                    "Using verified TLS with inline certificates"
-                );
+        impl TryFrom<TlsPolicy> for DomainConnector {
+            type Error = IoError;
 
-                let builder = ConnectorBuilder::identity(IdentityBuilder::from_x509(
-                    X509PemBuilder::from_reader(&mut tls.cert.as_bytes())?,
-                    PrivateKeyBuilder::from_reader(&mut tls.key.as_bytes())?,
-                )?)?
-                .add_root_certificate(X509PemBuilder::from_reader(&mut tls.ca_cert.as_bytes())?)?;
+            fn try_from(config: TlsPolicy) -> Result<Self, Self::Error> {
+                use std::io::ErrorKind as IoErrorKind;
 
-                // disable certificate verification for mac only!
-                let builder = if cfg!(target_os = "macos") {
-                    builder.no_cert_verification()
-                } else {
-                    builder
-                };
 
-                Ok(Box::new(TlsDomainConnector::new(
-                    builder.build(),
-                    tls.domain,
-                )))
+                use fluvio_future::net::certs::CertBuilder;
+                use fluvio_future::openssl:: {TlsDomainConnector,TlsConnector,TlsAnonymousConnector};
+                use fluvio_future::openssl::certs::{IdentityBuilder,X509PemBuilder,PrivateKeyBuilder};
+
+
+                match config {
+                    TlsPolicy::Disabled => Ok(Box::new(DefaultDomainConnector::new())),
+                    TlsPolicy::Anonymous => {
+                        info!("Using anonymous TLS");
+                        let builder = TlsConnector::builder()
+                                .map_err(|err| IoError::new(IoErrorKind::InvalidData, err))?
+                                .with_hostname_vertification_disabled()
+                                .map_err(|err| IoError::new(IoErrorKind::InvalidData, err))?;
+
+                        let connector: TlsAnonymousConnector = builder.build().into();
+                        Ok(Box::new(connector))
+
+                    }
+                    TlsPolicy::Verified(TlsConfig::Files(tls)) => {
+                        info!(
+                            domain = &*tls.domain,
+                            "Using verified TLS with certificates from paths"
+                        );
+
+                        let builder = TlsConnector::builder()
+                            .map_err(|err| IoError::new(IoErrorKind::InvalidData, err))?
+                            .with_identity(
+                                IdentityBuilder::from_x509(
+                                    X509PemBuilder::from_path(&tls.cert)?,
+                                    PrivateKeyBuilder::from_path(&tls.key)?
+                                )?
+                            )
+                            .map_err(|err| IoError::new(IoErrorKind::InvalidData, err))?
+                            .add_root_certificate(
+                                X509PemBuilder::from_path(&tls.ca_cert)?
+                                .build()?
+                            )
+                            .map_err(|err| IoError::new(IoErrorKind::InvalidData, err))?;
+
+
+                        Ok(Box::new(TlsDomainConnector::new(
+                            builder.build(),
+                            tls.domain,
+                        )))
+                    }
+                    TlsPolicy::Verified(TlsConfig::Inline(tls)) => {
+                        info!(
+                            domain = &*tls.domain,
+                            "Using verified TLS with inline certificates"
+                        );
+                        let builder = TlsConnector::builder()
+                            .map_err(|err| IoError::new(IoErrorKind::InvalidData, err))?
+                            .with_identity(
+                                IdentityBuilder::from_x509(
+                                    X509PemBuilder::from_reader(&mut tls.cert.as_bytes())?,
+                                    PrivateKeyBuilder::from_reader(&mut tls.key.as_bytes())?
+                                )?
+                            )
+                            .map_err(|err| IoError::new(IoErrorKind::InvalidData, err))?
+                            .add_root_certificate(
+                                X509PemBuilder::from_reader(&mut tls.ca_cert.as_bytes())?
+                                .build()?
+                            )
+                            .map_err(|err| IoError::new(IoErrorKind::InvalidData, err))?;
+
+
+                        Ok(Box::new(TlsDomainConnector::new(
+                            builder.build(),
+                            tls.domain,
+                        )))
+                    }
+                }
             }
         }
     }
-}
-#[cfg(target_arch = "wasm32")]
-impl TryFrom<TlsPolicy> for DomainConnector {
-    type Error = IoError;
 
-    fn try_from(_config: TlsPolicy) -> Result<Self, Self::Error> {
-        info!("Using Default Domain connector for wasm");
-        Ok(Box::new(DefaultDomainConnector::new()))
-    }
 }
