@@ -1,5 +1,6 @@
 use std::sync::Arc;
 
+use fluvio_sc_schema::objects::ObjectApiWatchRequest;
 use tracing::{debug, instrument};
 
 use fluvio_socket::SharedMultiplexerSocket;
@@ -70,7 +71,9 @@ impl MetadataStores {
         use dataplane::api::RequestMessage;
         use fluvio_sc_schema::objects::WatchRequest;
 
-        let mut req_msg = RequestMessage::new_request(WatchRequest::Spu(0));
+        let watch_request: WatchRequest<SpuSpec> = WatchRequest::default();
+        let watch_req: ObjectApiWatchRequest = watch_request.into();
+        let mut req_msg = RequestMessage::new_request(watch_req);
         req_msg.get_mut_header().set_api_version(self.watch_version);
 
         debug!("create spu metadata stream");
@@ -92,7 +95,9 @@ impl MetadataStores {
 
         debug!("start watch for partition");
 
-        let req_msg = RequestMessage::new_request(WatchRequest::Partition(0));
+        let watch_request: WatchRequest<PartitionSpec> = WatchRequest::default();
+        let watch_req: ObjectApiWatchRequest = watch_request.into();
+        let req_msg = RequestMessage::new_request(watch_req);
         let async_response = self.socket.create_stream(req_msg, 10).await?;
 
         MetadataSyncController::<PartitionSpec>::start(
@@ -111,7 +116,9 @@ impl MetadataStores {
 
         debug!("start watch for topic");
 
-        let req_msg = RequestMessage::new_request(WatchRequest::Topic(0));
+        let watch_request: WatchRequest<TopicSpec> = WatchRequest::default();
+        let watch_req: ObjectApiWatchRequest = watch_request.into();
+        let req_msg = RequestMessage::new_request(watch_req);
         let async_response = self.socket.create_stream(req_msg, 10).await?;
 
         MetadataSyncController::<TopicSpec>::start(
